@@ -22,17 +22,22 @@ import warnings
 from structlog._compat import OrderedDict
 from structlog._generic import BoundLogger
 from structlog._loggers import (
-    PrintLogger,
+    PrintLoggerFactory,
 )
 from structlog.processors import (
     KeyValueRenderer,
+    StackInfoRenderer,
     format_exc_info,
 )
 
-_BUILTIN_DEFAULT_PROCESSORS = [format_exc_info, KeyValueRenderer()]
+_BUILTIN_DEFAULT_PROCESSORS = [
+    StackInfoRenderer(),
+    format_exc_info,
+    KeyValueRenderer()
+]
 _BUILTIN_DEFAULT_CONTEXT_CLASS = OrderedDict
 _BUILTIN_DEFAULT_WRAPPER_CLASS = BoundLogger
-_BUILTIN_DEFAULT_LOGGER_FACTORY = PrintLogger
+_BUILTIN_DEFAULT_LOGGER_FACTORY = PrintLoggerFactory()
 _BUILTIN_CACHE_LOGGER_ON_FIRST_USE = False
 
 
@@ -54,7 +59,7 @@ Global defaults used when arguments to :func:`wrap_logger` are omitted.
 """
 
 
-def get_logger(**initial_values):
+def get_logger(*args, **initial_values):
     """
     Convenience function that returns a logger according to configuration.
 
@@ -63,6 +68,9 @@ def get_logger(**initial_values):
     >>> log.msg('hello', x=42)
     y=23 x=42 event='hello'
 
+    :param args: *Optional* positional arguments that are passed unmodified to
+        the logger factory.  Therefore it depends on the factory what they
+        mean.
     :param initial_values: Values that are used to pre-populate your contexts.
 
     :rtype: A proxy that creates a correctly configured bound logger when
@@ -72,8 +80,11 @@ def get_logger(**initial_values):
 
     If you prefer CamelCase, there's an alias for your reading pleasure:
     :func:`structlog.getLogger`.
+
+    .. versionadded:: 0.4.0
+        `args`
     """
-    return wrap_logger(None, **initial_values)
+    return wrap_logger(None, logger_factory_args=args, **initial_values)
 
 
 getLogger = get_logger
@@ -87,7 +98,7 @@ stick out like a sore thumb in frameworks like Twisted or Zope.
 
 def wrap_logger(logger, processors=None, wrapper_class=None,
                 context_class=None, cache_logger_on_first_use=None,
-                **initial_values):
+                logger_factory_args=None, **initial_values):
     """
     Create a new bound logger for an arbitrary `logger`.
 
@@ -101,11 +112,16 @@ def wrap_logger(logger, processors=None, wrapper_class=None,
     *is* possible.
 
     :param initial_values: Values that are used to pre-populate your contexts.
+    :param tuple logger_factory_args: Values that are passed unmodified as
+        ``*logger_factory_args`` to the logger factory if not `None`.
 
     :rtype: A proxy that creates a correctly configured bound logger when
         necessary.
 
     See :func:`configure` for the meaning of the rest of the arguments.
+
+    .. versionadded:: 0.4.0
+        `logger_factory_args`
     """
     return BoundLoggerLazyProxy(
         logger,
@@ -114,6 +130,7 @@ def wrap_logger(logger, processors=None, wrapper_class=None,
         context_class=context_class,
         cache_logger_on_first_use=cache_logger_on_first_use,
         initial_values=initial_values,
+        logger_factory_args=logger_factory_args,
     )
 
 
@@ -132,20 +149,18 @@ def configure(processors=None, wrapper_class=None, context_class=None,
 
     :param list processors: List of processors.
     :param type wrapper_class: Class to use for wrapping loggers instead of
-        :class:`structlog.BoundLogger`.
-
-        See :doc:`standard-library`, :doc:`twisted`, and
-        :doc:`custom-wrappers`.
-    :param context_class: Class to be used for internal dictionary.
-    :param callable logger_factory:
+        :class:`structlog.BoundLogger`.  See :doc:`standard-library`,
+        :doc:`twisted`, and :doc:`custom-wrappers`.
+    :param type context_class: Class to be used for internal context keeping.
+    :param callable logger_factory: Factory to be called to create a new
+        logger that shall be wrapped.
     :param bool cache_logger_on_first_use: `wrap_logger` doesn't return an
         actual wrapped logger but a proxy that assembles one when it's first
         used.  If this option is set to `True`, this assembled logger is
-        cached.
+        cached.  See :doc:`performance`.
 
-        See :doc:`performance`.
-
-        .. versionadded:: 0.3.0
+    .. versionadded:: 0.3.0
+        `cache_logger_on_first_use`
     """
     _CONFIG.is_configured = True
     if processors is not None:
@@ -179,13 +194,14 @@ def reset_defaults():
     """
     Resets global default values to builtins.
 
-    That means [:func:`~structlog.processors.format_exc_info`,
+    That means [:class:`~structlog.processors.StackInfoRenderer`,
+    :func:`~structlog.processors.format_exc_info`,
     :class:`~structlog.processors.KeyValueRenderer`] for *processors*,
     :class:`~structlog.BoundLogger` for *wrapper_class*, ``OrderedDict`` for
-    *context_class*, :class:`~structlog.PrintLogger` for *logger_factory*, and
-    `False` for *cache_logger_on_first_use*.
+    *context_class*, :class:`~structlog.PrintLoggerFactory` for
+    *logger_factory*, and `False` for *cache_logger_on_first_use*.
 
-    Also sets the global class attribute :attr:`is_configured` to `True`.
+    Also sets the global class attribute :attr:`is_configured` to `False`.
     """
     _CONFIG.is_configured = False
     _CONFIG.default_processors = _BUILTIN_DEFAULT_PROCESSORS[:]
@@ -206,23 +222,28 @@ class BoundLoggerLazyProxy(object):
 
     If and only if configuration says so, that actual BoundLogger is cached on
     first usage.
+
+    .. versionchanged:: 0.4.0
+        Added support for `logger_factory_args`.
     """
     def __init__(self, logger, wrapper_class=None, processors=None,
                  context_class=None, cache_logger_on_first_use=None,
-                 initial_values=None):
+                 initial_values=None, logger_factory_args=None):
         self._logger = logger
         self._wrapper_class = wrapper_class
         self._processors = processors
         self._context_class = context_class
         self._cache_logger_on_first_use = cache_logger_on_first_use
         self._initial_values = initial_values or {}
+        self._logger_factory_args = logger_factory_args or ()
 
     def __repr__(self):
         return (
             '<BoundLoggerLazyProxy(logger={0._logger!r}, wrapper_class='
             '{0._wrapper_class!r}, processors={0._processors!r}, '
             'context_class={0._context_class!r}, '
-            'initial_values={0._initial_values!r})>'.format(self)
+            'initial_values={0._initial_values!r}, '
+            'logger_factory_args={0._logger_factory_args!r})>'.format(self)
         )
 
     def bind(self, **new_values):
@@ -235,7 +256,7 @@ class BoundLoggerLazyProxy(object):
             ctx = _CONFIG.default_context_class(self._initial_values)
         cls = self._wrapper_class or _CONFIG.default_wrapper_class
         if not self._logger:
-                self._logger = _CONFIG.logger_factory()
+            self._logger = _CONFIG.logger_factory(*self._logger_factory_args)
         logger = cls(
             self._logger,
             processors=self._processors or _CONFIG.default_processors,
