@@ -21,10 +21,32 @@ library <http://docs.python.org/>`_.
 from __future__ import absolute_import, division, print_function
 
 import logging
-import sys
 
 from structlog._base import BoundLoggerBase
 from structlog._exc import DropEvent
+from structlog._compat import PY3
+from structlog._frames import _format_stack, _find_first_app_frame_and_name
+
+
+class _FixedFindCallerLogger(logging.Logger):
+    """
+    Change the behavior of findCaller to cope with structlog's extra frames.
+    """
+    def findCaller(self, stack_info=False):
+        """
+        Finds the first caller frame outside of structlog so that the caller
+        info is populated for wrapping stdlib.
+        This logger gets set as the default one when using LoggerFactory.
+        """
+        f, name = _find_first_app_frame_and_name(['logging'])
+        if PY3:  # pragma: nocover
+            if stack_info:
+                sinfo = _format_stack(f)
+            else:
+                sinfo = None
+            return f.f_code.co_filename, f.f_lineno, f.f_code.co_name, sinfo
+        else:
+            return f.f_code.co_filename, f.f_lineno, f.f_code.co_name
 
 
 class BoundLogger(BoundLoggerBase):
@@ -77,23 +99,45 @@ class LoggerFactory(object):
     """
     Build a standard library logger when an *instance* is called.
 
+    Sets a custom logger using `logging.setLogggerClass` so variables in
+    log format are expanded properly.
+
     >>> from structlog import configure
     >>> from structlog.stdlib import LoggerFactory
     >>> configure(logger_factory=LoggerFactory())
+
+    :param ignore_frame_names: When guessing the name of a logger, skip frames
+        whose names *start* with one of these.  For example, in pyramid
+        applications you'll want to set it to
+        ``['venusian', 'pyramid.config']``.
+    :type ignore_frame_names: `list` of `str`
     """
-    def __call__(self):
+    def __init__(self, ignore_frame_names=None):
+        self._ignore = ignore_frame_names
+        logging.setLoggerClass(_FixedFindCallerLogger)
+
+    def __call__(self, *args):
         """
-        Deduces the caller's module name and create a stdlib logger.
+        Deduce the caller's module name and create a stdlib logger.
+
+        If an optional argument is passed, it will be used as the logger name
+        instead of guesswork.  This optional argument would be passed from the
+        :func:`structlog.get_logger` call.  For example
+        ``struclog.get_logger('foo')`` would cause this method to be called
+        with ``'foo'`` as its first positional argument.
 
         :rtype: `logging.Logger`
-        """
-        f = sys._getframe()
-        name = f.f_globals['__name__']
 
-        # We skip all frames that originate from within structlog.
-        while name.startswith('structlog.'):
-            f = f.f_back
-            name = f.f_globals['__name__']
+        .. versionchanged:: 0.4.0
+            Added support for optional positional arguments.  Using the first
+            one for naming the constructed logger.
+        """
+        if args:
+            return logging.getLogger(args[0])
+
+        # We skip all frames that originate from within structlog or one of the
+        # configured names.
+        _, name = _find_first_app_frame_and_name(self._ignore)
         return logging.getLogger(name)
 
 
